@@ -4,16 +4,15 @@ import asyncio
 import logging
 from asyncio import DatagramTransport
 from asyncio.events import AbstractEventLoop
-from ipaddress import IPv4Address, IPv6Address
+from ipaddress import ip_address
 from typing import Awaitable, Callable, Mapping, MutableMapping, Optional
 
 from async_upnp_client.ssdp import (
     SSDP_IP_V4,
     SSDP_IP_V6,
     SSDP_MX,
+    SSDP_PORT,
     SSDP_ST_ALL,
-    SSDP_TARGET_V4,
-    SSDP_TARGET_V6,
     AddressTupleVXType,
     IPvXAddress,
     SsdpProtocol,
@@ -35,30 +34,29 @@ class SSDPListener:  # pylint: disable=too-many-arguments,too-many-instance-attr
         async_callback: Callable[[Mapping[str, str]], Awaitable],
         loop: Optional[AbstractEventLoop] = None,
         source_ip: Optional[IPvXAddress] = None,
-        target_ip: Optional[IPvXAddress] = None,
+        target: Optional[AddressTupleVXType] = None,
         timeout: int = SSDP_MX,
         service_type: str = SSDP_ST_ALL,
+        async_connect_callback: Optional[Callable[[], Awaitable]] = None,
     ) -> None:
         """Init the ssdp listener class."""
         self.async_callback = async_callback
+        self.async_connect_callback = async_connect_callback
         self.service_type = service_type
         self.source_ip = source_ip
-        self.target_ip = target_ip
         self.timeout = timeout
         self.loop = loop
+        self._target: Optional[AddressTupleVXType] = target
         self._target_host: Optional[str] = None
-        self._target_data: Optional[AddressTupleVXType] = None
-        self._target: Optional[AddressTupleVXType] = None
         self._transport: Optional[DatagramTransport] = None
 
     def async_search(
         self, override_target: Optional[AddressTupleVXType] = None
     ) -> None:
         """Start an SSDP search."""
-        assert self._target_data is not None, "Call async_start() first"
-        packet = build_ssdp_search_packet(
-            self._target_data, self.timeout, self.service_type
-        )
+        assert self._target_host is not None, "Call async_start() first"
+        assert self._target is not None, "Call async_start() first"
+        packet = build_ssdp_search_packet(self._target, self.timeout, self.service_type)
         _LOGGER.debug("Sending M-SEARCH packet, transport: %s", self._transport)
         _LOGGER_TRAFFIC_SSDP.debug("Sending M-SEARCH packet: %s", packet)
         assert self._transport is not None
@@ -78,28 +76,28 @@ class SSDPListener:  # pylint: disable=too-many-arguments,too-many-instance-attr
 
     async def _async_on_connect(self, transport: DatagramTransport) -> None:
         self._transport = transport
-        self.async_search()
+        if self.async_connect_callback:
+            await self.async_connect_callback()
 
     async def async_start(self) -> None:
         """Start the listener."""
-        if self.target_ip is None:
+        if self._target is None:
             if self.source_ip and self.source_ip.version == 6:
-                self.target_ip = IPv6Address(SSDP_IP_V6)
+                self._target = (SSDP_IP_V6, SSDP_PORT)
             else:
-                self.target_ip = IPv4Address(SSDP_IP_V4)
+                self._target = (SSDP_IP_V4, SSDP_PORT)
+
+        target_ip: IPvXAddress = ip_address(self._target[0])
+
         if self.source_ip is None:
-            self.source_ip = get_source_ip_from_target_ip(self.target_ip)
-
-        sock, source, self._target = get_ssdp_socket(self.source_ip, self.target_ip)
-
+            self.source_ip = get_source_ip_from_target_ip(target_ip)
         # We use the standard target in the data of the announce since
         # many implementations will ignore the request otherwise
-        if self.target_ip.version == 6:
-            self._target_data = SSDP_TARGET_V6
-        else:
-            self._target_data = SSDP_TARGET_V4
+        sock, source, _ = get_ssdp_socket(
+            self.source_ip, target_ip, port=self._target[1]
+        )
 
-        if not self.target_ip.is_multicast:
+        if not target_ip.is_multicast:
             self._target_host = get_host_string(self._target)
         else:
             self._target_host = ""
@@ -126,14 +124,26 @@ async def async_search(
     service_type: str = SSDP_ST_ALL,
     source_ip: Optional[IPvXAddress] = None,
     loop: Optional[AbstractEventLoop] = None,
-    target_ip: Optional[IPvXAddress] = None,
+    target: Optional[AddressTupleVXType] = None,
 ) -> None:
     """Discover devices via SSDP."""
     # pylint: disable=too-many-arguments
     loop_: AbstractEventLoop = loop or asyncio.get_event_loop()
+    listener: Optional[SSDPListener] = None
+
+    async def _async_connected() -> None:
+        nonlocal listener
+        assert listener is not None
+        listener.async_search()
 
     listener = SSDPListener(
-        async_callback, loop_, source_ip, target_ip, timeout, service_type
+        async_callback,
+        loop_,
+        source_ip,
+        target,
+        timeout,
+        service_type,
+        async_connect_callback=_async_connected,
     )
 
     await listener.async_start()
